syntax = "proto3";

package discord_protos.premium_marketing.v1;

message PremiumMarketingComponentProperties {
  message FeatureCard {
    string header = 1;
    string pill = 2;
    string body = 3;
    string image_link = 4;
    string image_link_light_theme = 5;
  }

  enum ButtonAction {
    BUTTON_ACTION_UNSPECIFIED = 0;
    BUTTON_ACTION_OPEN_MARKETING_PAGE = 1;
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL = 2;
    BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL = 3;
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER = 4;
    BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL = 5;
  }

  message SubscriptionButton {
    string copy = 1;
    ButtonAction button_action = 2;
  }

  message Subtitle {
    string link = 1;
    string locale = 2;
    bool is_default = 3;
  }

  message Variant1Storage {
    map<string, string> hero_art_localized_video_links_dark_theme = 1;
    map<string, string> hero_art_localized_video_links_light_theme = 2;
    map<string, string> hero_art_video_subtitle_links = 3;
  }

  message AnnouncementModalVariant1Properties {
    string header = 1;
    string subheader = 2;
    string video_link = 3;
    string help_article_id = 4;
    repeated FeatureCard feature_cards = 5;
    optional SubscriptionButton button = 6;
    string dismiss_key = 7;
    string hero_art_video_link_light_theme = 8;
    string hero_art_image_link_dark_theme = 9;
    string hero_art_image_link_light_theme = 10;
    string modal_top_pill = 11;
    string body = 12;
    repeated Subtitle hero_art_video_subtitles = 13;
    optional Variant1Storage storage = 14;
  }

  message PremiumTab {
    string badge_label = 1;
    string acknowledged_badge_label = 2;
  }

  message MarketingPageBannerButton {
    string copy = 1;
    ButtonAction button_action = 2;
  }

  message MarketingPageBanner {
    string asset_url = 1;
    string header = 2;
    string body = 3;
    string help_article_id = 4;
    optional MarketingPageBannerButton button = 5;
  }

  message PaymentModalBanner {
    string asset_url = 1;
    string header = 2;
    string body = 3;
  }

  message CTAButton {
    string copy = 1;
    ButtonAction button_action = 2;
  }

  enum DismissibleContent {
    DISMISSIBLE_CONTENT_HUB_WAITLIST_UPSELL = 0;
    DISMISSIBLE_CONTENT_APPLICATION_COMMAND_TOOLTIP = 1;
    DISMISSIBLE_CONTENT_HUB_EVENT_HEADER_UPSELL = 2;
    DISMISSIBLE_CONTENT_CHANNELINFO_CHANNELBANNER_NOTICE = 3;
    DISMISSIBLE_CONTENT_ACCOUNT_MULTIACCOUNT_TOOLTIP = 4;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_INVITE = 6;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_HUBLINK = 7;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_QUICKSWITCHER = 8;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_PREMIUM_GUILD_SUBSCRIPTION = 9;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_GUILD_BANNER = 11;
    DISMISSIBLE_CONTENT_GUILD_HEADER_EVENT_UPSELL = 12;
    DISMISSIBLE_CONTENT_GUILD_HEADER_ANIMATED_GUILD_BANNER = 15;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_DOWNLOAD = 16;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_SPOTIFY = 17;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_PLAYSTATION = 18;
    DISMISSIBLE_CONTENT_ACTIVITIES_SUNSET_COACH_MARK = 20;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_PROMO = 21;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_TWO_TRIAL_ENDING = 22;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_REACTIVATE = 23;
    DISMISSIBLE_CONTENT_PREMIUM_5TH_ANNIVERSARY_MODAL = 24;
    DISMISSIBLE_CONTENT_GUILD_JOIN_FEEDBACK_MODAL = 25;
    DISMISSIBLE_CONTENT_VOICE_QUALITY_BOOSTING_UPSELL_TOOLTIP = 26;
    DISMISSIBLE_CONTENT_ACTIVITIES_EARLY_USER_COACH_MARK = 27;
    DISMISSIBLE_CONTENT_GUILD_HEADER_SERVER_DISCOVERY_TOOLTIP = 28;
    DISMISSIBLE_CONTENT_ACTIVITIES_TUTORIAL_COACH_MARK = 29;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_LOCALIZED_PRICING = 33;
    DISMISSIBLE_CONTENT_SOUNDBOARD_EDUCATION = 35;
    DISMISSIBLE_CONTENT_GUILD_HEADER_ROLE_SUBSCRIPTION_UPSELL = 37;
    DISMISSIBLE_CONTENT_CALL_CHAT_BUTTON_TEXT_IN_VOICE_COACH_MARK = 38;
    DISMISSIBLE_CONTENT_GUILD_DISCOVERY_LANDING_PAGE_SETTINGS_UPSELL = 39;
    DISMISSIBLE_CONTENT_GUILD_INSIGHTS_ACCESS_RATE_NEW = 40;
    DISMISSIBLE_CONTENT_NOW_PLAYING_CONSENT_CARD = 41;
    DISMISSIBLE_CONTENT_GUILD_HEADER_BOOSTING_LOW_PRICE_EXPERIMENT_TOOLTIP = 42;
    DISMISSIBLE_CONTENT_FORUM_CHANNEL_UPSELL_MODAL = 44;
    DISMISSIBLE_CONTENT_POGGERMODE_BIRTHDAY_EDUCATION_TOOLTIP = 46;
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_HALFSHEET = 47;
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_THEMED = 48;
    DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_BLURPLE = 49;
    DISMISSIBLE_CONTENT_GUILD_FEED_NUX_CARD = 50;
    DISMISSIBLE_CONTENT_GUILD_HEADER_FREE_STICKER_SLOTS_TOOLTIP = 52;
    DISMISSIBLE_CONTENT_ACTIVITIES_NITRO_TUTORIAL_COACH_MARK_V2 = 53;
    DISMISSIBLE_CONTENT_ACTIVITIES_TEXT_INPUT_BUTTON_SPARKLES = 55;
    DISMISSIBLE_CONTENT_GUILD_DELETE_FEEDBACK = 56;
    DISMISSIBLE_CONTENT_GUILD_LEAVE_FEEDBACK = 57;
    DISMISSIBLE_CONTENT_AUTH_SESSIONS_NEW = 63;
    DISMISSIBLE_CONTENT_DONUT_MOBILE_NUX = 65;
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_MWEB_PURCHASE_UPSELL = 66;
    DISMISSIBLE_CONTENT_FORUM_CHANNEL_HELPER_CARD = 67;
    DISMISSIBLE_CONTENT_PASSPORT_USER_SETTINGS = 70;
    DISMISSIBLE_CONTENT_SUMMER_BOGO_ANNOUNCEMENT = 71;
    DISMISSIBLE_CONTENT_COMMANDS_MIGRATION_UPSELL_MODAL = 72;
    DISMISSIBLE_CONTENT_FILE_LIMIT_UPLOAD_COACH_MARK = 73;
    DISMISSIBLE_CONTENT_DONUT_DESKTOP_NUX = 77;
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_EMOJI_UPSELL = 79;
    DISMISSIBLE_CONTENT_PREMIUM_SUBSCRIPTION_UPSELL_EMOJI_PICKER_TOP_OF_LIST = 80;
    DISMISSIBLE_CONTENT_STAGE_RAISED_HAND_MOVED = 81;
    DISMISSIBLE_CONTENT_XBOX_ONE_WAY_RECONNECT = 82;
    DISMISSIBLE_CONTENT_XBOX_VOICE_DESKTOP_SETTINGS_UPSELL_POPOUT = 84;
    DISMISSIBLE_CONTENT_HUB_BACK_TO_SCHOOL_UPSELL = 85;
    DISMISSIBLE_CONTENT_STUDENT_HUB_PRIVACY_SETTINGS_TOOLTIP = 86;
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_VOICE_CONTROLS_TOGGLE_NUX = 89;
    DISMISSIBLE_CONTENT_PROFILE_THEMES_SETTINGS_VIEWED_V2 = 92;
    DISMISSIBLE_CONTENT_CHANNEL_LIST_OPT_IN_NUX = 94;
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_NUX = 95;
    DISMISSIBLE_CONTENT_PROFILE_THEMES_NEW_BADGE = 96;
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL = 97;
    DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NUX = 98;
    DISMISSIBLE_CONTENT_RNA_CHANGELOG_HC_NOTICE = 99;
    DISMISSIBLE_CONTENT_MESSAGE_REQUEST_SETTINGS_COACH_MARK = 100;
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL_2 = 101;
    DISMISSIBLE_CONTENT_GUILD_AUTOMOD_REGEX_UPSELL = 102;
    DISMISSIBLE_CONTENT_CONNECTIONS_NUX = 108;
    DISMISSIBLE_CONTENT_XBOX_VOICE_SURVEY_NAGBAR = 110;
    DISMISSIBLE_CONTENT_PS_ONE_WAY_RECONNECT = 112;
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_PROFILE_CUSTOMIZATION = 116;
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_BOOSTING = 117;
    DISMISSIBLE_CONTENT_NITRODUCTION_STEP_CUSTOM_EMOJI = 118;
    DISMISSIBLE_CONTENT_NEW_CRUNCHYROLL_CONNECTION = 119;
    DISMISSIBLE_CONTENT_APP_DIRECTORY_UPSELL_MODAL = 121;
    DISMISSIBLE_CONTENT_GUILD_HEADER_COMMUNITY_ONBOARDING_ADMIN_UPSELL = 124;
    DISMISSIBLE_CONTENT_COMMUNITY_ONBOARDING_NEW_BADGE = 125;
    DISMISSIBLE_CONTENT_VERIFIED_ROLES_COACH_MARK = 127;
    DISMISSIBLE_CONTENT_BLACK_FRIDAY_2022_BOGO_ANNOUNCEMENT_MODAL = 130;
    DISMISSIBLE_CONTENT_GG_ANNOUNCEMENT = 132;
    DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NEW_BADGE_NUX = 133;
    DISMISSIBLE_CONTENT_CREATOR_PROMO_PAGE_COACH_MARK = 134;
    DISMISSIBLE_CONTENT_CREATOR_MONETIZATION_ONBOARDING_V2_UPSELL = 136;
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL = 137;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_ONE_TIME_PAYMENT_PAST_DUE = 138;
    DISMISSIBLE_CONTENT_DROPS_GO_LIVE_BANNER_NOTICE_HALO = 139;
    DISMISSIBLE_CONTENT_DROPS_ELIGIBILITY_ENROLLMENT_TOOLTIP_HALO = 140;
    DISMISSIBLE_CONTENT_DROPS_QUEST_COMPLETION_TOOLTIP_HALO = 141;
    DISMISSIBLE_CONTENT_NAGBAR_BOUNCED_EMAIL_NOTICE = 147;
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_CHANNEL_NOTICE = 151;
    DISMISSIBLE_CONTENT_CONSOLE_PTT_DISABLE_ALERT = 152;
    DISMISSIBLE_CONTENT_ACTIVITIES_MINI_SHELF_SPARKLES = 153;
    DISMISSIBLE_CONTENT_DROPS_ENDED_INCOMPLETE_HALO = 154;
    DISMISSIBLE_CONTENT_GDM_INVITE_REMINDER = 157;
    DISMISSIBLE_CONTENT_LINKED_ROLE_ADMIN_GUILD = 163;
    DISMISSIBLE_CONTENT_NAGBAR_ACTIVATE_SERVER_SUBSCRIPTION = 164;
    DISMISSIBLE_CONTENT_BURST_REACTION_BUTTON_SPARKLE = 165;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_0_TRIAL_ENDING = 166;
    DISMISSIBLE_CONTENT_VC_TILE_ACTIVITIES_ENTRY_POINT = 167;
    DISMISSIBLE_CONTENT_BURST_REACTION_COACHMARK = 169;
    DISMISSIBLE_CONTENT_BURST_REACTIONS_REMOVE_MODAL = 170;
    DISMISSIBLE_CONTENT_BURST_REACTION_NITRO_TOOLTIP = 171;
    DISMISSIBLE_CONTENT_CLIENT_THEMES_SETTINGS_BADGE = 173;
    DISMISSIBLE_CONTENT_CLIENT_THEMES_COACHMARK = 174;
    DISMISSIBLE_CONTENT_CLIENT_THEMES_SPARKLE_PREVIEW = 175;
    DISMISSIBLE_CONTENT_STAGE_V2_UPSELL = 176;
    DISMISSIBLE_CONTENT_QUEST_1_ENROLLMENT_TOOLTIP = 177;
    DISMISSIBLE_CONTENT_QUEST_1_COMPLETION_TOOLTIP = 178;
    DISMISSIBLE_CONTENT_QUEST_1_GO_LIVE_BANNER = 179;
    DISMISSIBLE_CONTENT_QUEST_1_ENDED_INCOMPLETE = 180;
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EXPERIENCE = 181;
    DISMISSIBLE_CONTENT_APP_DIRECTORY_SERVER_SETUP_UPSELL_MODAL = 182;
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_FILE_UPLOAD_COMPOSER_TOOLTIP = 183;
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_STICKER_PICKER_COMPOSER_TOOLTIP = 184;
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EMOJI_PICKER_COMPOSER_TOOLTIP = 185;
    DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_SERVER_MENU_TOOLTIP = 186;
    DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_DM = 189;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_NITRO_MARKETING = 190;
    DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_ANNOUNCEMENT_MODAL = 191;
    DISMISSIBLE_CONTENT_CLYDE_GUILD_HEADER_NUX = 193;
    DISMISSIBLE_CONTENT_CLYDE_CHAT_BAR_NUX = 194;
    DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_GUILD = 195;
    DISMISSIBLE_CONTENT_ACTIVITY_GDM_CALL_TOOLTIP = 196;
    DISMISSIBLE_CONTENT_ACTIVITY_GDM_ROCKET_SPARKLE = 197;
    DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_NITRO_TAB_BADGE = 205;
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_IAP_UPSELL = 206;
    DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_PIP_FAB_NUX = 208;
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_HEADER = 210;
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_NAGBAR = 212;
    DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL_V2 = 213;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_FREE_USER_FIRST_SENT = 214;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_TOOLTIP_COACHMARK = 215;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_POMELO = 217;
    DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_NEW_INDICATOR = 218;
    DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_CONTEXT_MENU_NEW_INDICATOR = 219;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_TAB_SPARKLE = 220;
    DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_1_SPARKLES = 221;
    DISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_2_SPARKLES = 222;
    DISMISSIBLE_CONTENT_MJ_NEW_USER_CHAT_BAR = 223;
    DISMISSIBLE_CONTENT_CHANNEL_NOTICE_CLYDE_NUX = 224;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_FIRST_SENT = 227;
    DISMISSIBLE_CONTENT_COMMUNITY_GUILD_SETTINGS_SAFETY = 228;
    DISMISSIBLE_CONTENT_FRIEND_FINDER_FIRST_TIME_BADGE = 229;
    DISMISSIBLE_CONTENT_SHARE_NITRO_BUTTON_SPARKLES = 230;
    DISMISSIBLE_CONTENT_PREMIUM_MOBILE_TRIAL_USER_SETTINGS_AVATAR_BADGE = 231;
    DISMISSIBLE_CONTENT_SOUNDBOARD_KEYBIND_TIP = 232;
    DISMISSIBLE_CONTENT_QUEST_2_ENROLLMENT_TOOLTIP = 234;
    DISMISSIBLE_CONTENT_QUEST_2_COMPLETION_TOOLTIP = 235;
    DISMISSIBLE_CONTENT_QUEST_2_GO_LIVE_BANNER = 236;
    DISMISSIBLE_CONTENT_QUEST_2_ENDED_INCOMPLETE = 237;
    DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_TIER_TEMPLATES = 238;
    DISMISSIBLE_CONTENT_MEDIA_CHANNEL_UPSELL = 243;
    DISMISSIBLE_CONTENT_ADD_FRIENDS_WIDGET = 244;
    DISMISSIBLE_CONTENT_YOU_TAB_AVATAR_ONBOARDING = 245;
    DISMISSIBLE_CONTENT_YOU_TAB_ABOUT_ME_ONBOARDING = 246;
    DISMISSIBLE_CONTENT_GUILD_HEADER_SUMMARIES_UPSELL = 247;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_COACHMARK_MOBILE = 250;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_SPARKLES_ACTION_SHEET_MOBILE = 251;
    DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_TIER_TEMPLATE_UPSELL = 252;
    DISMISSIBLE_CONTENT_EMOJI_PICKER_FAVORITE_EMOJIS_TIP = 253;
    DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_SETTINGS_NEW_BADGE_TIER_TEMPLATE = 254;
    DISMISSIBLE_CONTENT_SUPER_REACTIONS_MOBILE_FULLSCREEN_TAP_TO_DISMISS = 255;
    DISMISSIBLE_CONTENT_FAMILY_CENTER_NEW_BADGE = 256;
    DISMISSIBLE_CONTENT_CONSOLE_LOCAL_DETECT_CTA = 257;
    DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_EDUCATION_UPSELLS_MOBILE = 263;
    DISMISSIBLE_CONTENT_GUEST_VOICE_INVITES_MENU_ITEM_NEW_BADGE = 264;
    DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_OPEN_MEDIA_KEYBOARD_UPSELL_MOBILE = 265;
    DISMISSIBLE_CONTENT_GUILD_MEMBER_SAFETY_BANNER_NOTICE = 266;
    DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK = 271;
    DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_PICKER_UPSELL = 272;
    DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_SPARKLES = 274;
    DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_FLOATING_CTA = 275;
    DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_NEW_BADGE = 276;
    DISMISSIBLE_CONTENT_PROFILE_THEMES_FEATURE_EDUCATION_TOOLTIP_TAKE_2 = 277;
    DISMISSIBLE_CONTENT_VOICE_PANEL_BAD_CONNECTION_CTA = 278;
    DISMISSIBLE_CONTENT_PREMIUM_TRIAL_OFFER_MOBILE_ACTION_SHEET = 279;
    DISMISSIBLE_CONTENT_MEDIA_CHANNEL_MULTIPLE_THUMBNAIL_NOTICE = 280;
    DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_GO_LIVE_COACHMARK = 281;
    DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_CLIP_BUTTON_COACHMARK = 282;
    DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_COACHMARK = 283;
    DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_NEW_BADGE = 284;
    DISMISSIBLE_CONTENT_BROADCASTING_BROADCASTER_TOOLTIP = 285;
    DISMISSIBLE_CONTENT_BROADCASTING_VIEWER_TOOLTIP = 286;
    DISMISSIBLE_CONTENT_LAUNCH_PAD_PULL_TAB_NUX = 289;
    DISMISSIBLE_CONTENT_MEMBERS_LAUNCH_UPSELL = 294;
    DISMISSIBLE_CONTENT_SERVER_SHOP_PHANTOM_PREVIEW = 295;
    DISMISSIBLE_CONTENT_RECURRING_CONTACT_SYNC_PROMPT = 297;
    DISMISSIBLE_CONTENT_INVENTORY_TRY_PACKS_MODAL = 302;
    DISMISSIBLE_CONTENT_DEPRECATE_WIN32_MESSAGE = 305;
    DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_COACHMARK = 306;
    DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_BADGE = 307;
    DISMISSIBLE_CONTENT_CLYDE_AI_PERSONALITIES_NUX_MODAL = 312;
    DISMISSIBLE_CONTENT_NUX_GUILD_CHANNEL_EXPLAINER = 313;
    DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_DESKTOP = 316;
    DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_MOBILE = 317;
    DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME_OR_REDESIGN = 325;
    DISMISSIBLE_CONTENT_SEEN_OLD_DESIGN = 326;
    DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME = 335;
    DISMISSIBLE_CONTENT_FAVORITE_SERVER_ADD_TO_FAVORITES_COACHMARK = 336;
    DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK_ROLLBACK = 337;
    DISMISSIBLE_CONTENT_FRIEND_FINDER_CONTACTS_IN_NOTIFICATIONS = 338;
    DISMISSIBLE_CONTENT_OVERLAY_KEYBIND_NOTIFICATION = 340;
    DISMISSIBLE_CONTENT_CHANNEL_LIST_V2_BROWSE_CHANNELS_NUX = 343;
    DISMISSIBLE_CONTENT_HANG_STATUS_NEW_BADGE = 346;
    DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_TOOLTIP = 347;
    DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_NEW_BADGE = 348;
    DISMISSIBLE_CONTENT_SWIPE_TO_REPLY_COACHMARK = 349;
    DISMISSIBLE_CONTENT_MOBILE_ACCESSIBILITY_COLOR_SETTINGS = 350;
    DISMISSIBLE_CONTENT_POLLS_CHAT_INPUT_COACHMARK = 354;
    DISMISSIBLE_CONTENT_LOOTBOXES_ENTRYPOINT = 358;
    DISMISSIBLE_CONTENT_TENURE_REWARD_PENDING = 360;
    DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE = 361;
    DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE_CONFETTI = 363;
    DISMISSIBLE_CONTENT_GAME_ONE_USER_SIGNUPS = 364;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_SHY_COACHTIP = 365;
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_BOTS_BANNER = 366;
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_ACTIVITIES_BANNER = 367;
    DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_APPS_BANNER = 368;
    DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_MARKETING = 369;
    DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_HALF_SHEET = 370;
    DISMISSIBLE_CONTENT_GENSHIN_USER_SIGNUPS = 371;
    DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_BUTTON_NUX_V2 = 372;
    DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_MENU_NEW_BADGE = 373;
    DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_MODAL = 374;
    DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_BADGE = 375;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PROGRESS_BAR_TOGGLE = 377;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PREMIUM_TAB_BADGE = 380;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_LOFI_VIBES_COACHTIP = 382;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_GALAXY_COACHTIP = 383;
    DISMISSIBLE_CONTENT_CONTENT_INVENTORY_ONE_CLICK_REPLY_COACHTIP = 384;
    DISMISSIBLE_CONTENT_CHANNEL_LIST_CLAN_ADMIN_UPSELL = 385;
    DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_ADMIN_UPSELL = 386;
    DISMISSIBLE_CONTENT_MOBILE_NITRO_HOME_SETTINGS_BADGE = 387;
    DISMISSIBLE_CONTENT_BRAND_REFRESH_NEW_BADGE = 388;
    DISMISSIBLE_CONTENT_BRAND_REFRESH_BLURPLE_TWILIGHT_APP_ICON_BADGE = 389;
    DISMISSIBLE_CONTENT_BRAND_REFRESH_CLIENT_THEME_BADGE = 390;
    DISMISSIBLE_CONTENT_APP_LAUNCHER_USER_APP_BETA_NOTICE = 391;
    DISMISSIBLE_CONTENT_COLLECTIBLES_PIRATES_MOBILE_BADGING = 392;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_RETRO_AND_PIRATES_COACHTIP = 393;
    DISMISSIBLE_CONTENT_PRIDE_ICONS = 394;
    DISMISSIBLE_CONTENT_PRIDE_ICONS_COACHMARK = 395;
    DISMISSIBLE_CONTENT_PRIDE_ICONS_APPEARANCE_BADGE = 396;
    DISMISSIBLE_CONTENT_CLAN_TAG_WAITLIST = 397;
    DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_USER_UPSELL = 398;
    DISMISSIBLE_CONTENT_QUEST_HOME_FRIENDS_LIST_NEW_BADGE = 399;
    DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_FLIP = 400;
    DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_FLIP = 401;
    DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_FLIP = 402;
    DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_NITRO_BADGE = 403;
    DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_NITRO_BADGE = 404;
    DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_NITRO_BADGE = 405;
    DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_FLIP = 406;
    DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_BADGE = 407;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ARCADE_COACHTIP = 408;
    DISMISSIBLE_CONTENT_CHECKOUT_RECOVERY_NAGBAR = 409;
    DISMISSIBLE_CONTENT_PREMIUM_2024_JUNE_MARKETING_MODAL = 410;
    DISMISSIBLE_CONTENT_APP_LAUNCHER_GLOBAL_SEARCH_ONBOARDING = 411;
    DISMISSIBLE_CONTENT_NEW_GAMING_DISCOVERY_NOTIF = 412;
    DISMISSIBLE_CONTENT_NITRO_ON_PROFILE_SIDE_PANEL = 414;
    DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_DESKTOP_UTILITIES_NEW_BADGE = 415;
    DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_MOBILE_SHEET_NEW_BADGE = 416;
    DISMISSIBLE_CONTENT_SUMMER_2024_BOGO_ANNOUNCEMENT_MODAL = 417;
    DISMISSIBLE_CONTENT_GIFT_INVENTORY_QUESTS_MOVED_TO_QUEST_HOME = 421;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ENTRY_MARKETING = 422;
    DISMISSIBLE_CONTENT_CASH_APP_PAY_AWARENESS_NAGBAR = 423;
    DISMISSIBLE_CONTENT_ICYMI_ALPHA_UPSELL = 425;
    DISMISSIBLE_CONTENT_PASSWORDLESS_UPSELL = 427;
    DISMISSIBLE_CONTENT_CHANNEL_LINKED_LOBBY_EDUCATION_TOOLTIP = 429;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_DOJO_MARKETING = 431;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_STREAM_POPOUT = 432;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE = 433;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_BUTTON = 434;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_FIRST_IMPRESSION_MODAL = 435;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_PICKER = 436;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_ENDED_UPSELL = 437;
    DISMISSIBLE_CONTENT_VOICE_PANEL_ACTIVITIES_SHAPES_BUTTON_EDUCATION_TOOLTIP = 439;
    DISMISSIBLE_CONTENT_FOR_LATER_NOTIFICATIONS_COACHMARK = 440;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_THE_VAULT_MARKETING = 441;
    DISMISSIBLE_CONTENT_USER_DM_MUTE_FEEDBACK = 442;
    DISMISSIBLE_CONTENT_RAPIDASH_M3_DISCOVERY_UPSELL = 443;
    DISMISSIBLE_CONTENT_WHATS_NEW_TENURE_BADGE_REWARD = 444;
    DISMISSIBLE_CONTENT_FOR_LATER_POPOUT_COACHMARK = 445;
    DISMISSIBLE_CONTENT_GLOBAL_DISCOVERY_RAPIDASH_NOTIF = 448;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_BAND_MARKETING = 449;
    DISMISSIBLE_CONTENT_RAPIDASH_MORE_GUILDS_UPSELL = 452;
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_INITIAL_UPSELL = 453;
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MOBILE_SETTINGS_NOTICE = 454;
    DISMISSIBLE_CONTENT_RAPIDASH_RTC_BROWSE_GUILDS = 456;
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MARKETING_PAGE_BADGE = 457;
    DISMISSIBLE_CONTENT_USER_PROFILE_PREMIUM_AND_SHOP_ENTRY_POINTS = 458;
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_DESKTOP_MODAL = 462;
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_ICON = 467;
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_DESKTOP_FIRST_TIME_COACHMARK = 468;
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_MOBILE_FIRST_TIME_HALFSHEET = 469;
    DISMISSIBLE_CONTENT_GIFTING_PROMOTION_REMINDER = 470;
    DISMISSIBLE_CONTENT_CONSUMABLE_HD_POTION_UPSELL = 471;
    DISMISSIBLE_CONTENT_HD_STREAMING_POTION_MODAL_UPSELL = 472;
    DISMISSIBLE_CONTENT_HD_STREAMING_POTION_BANNER = 473;
    DISMISSIBLE_CONTENT_GIFTING_INTENT_FRIENDS_TAB_BADGE = 474;
    DISMISSIBLE_CONTENT_FRACTIONAL_NITRO_DURATION_LEFT_PILL = 476;
    DISMISSIBLE_CONTENT_RESTRICTED_ACCOUNTS_SETTING_NOTICE = 479;
    DISMISSIBLE_CONTENT_CONNECTIONS_XBOX_LINK_COACHMARK = 480;
    DISMISSIBLE_CONTENT_CONNECTIONS_NEW_CONSOLE_COACHMARK = 481;
    DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_NITRO_HOME_BADGE = 482;
    DISMISSIBLE_CONTENT_SOUNDMOJI_COACHMARK = 483;
    DISMISSIBLE_CONTENT_SOUNDMOJI_BADGE = 484;
    DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_SENDER_COACHMARK = 485;
    DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_BUTTON = 486;
    DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_PICKER = 487;
    DISMISSIBLE_CONTENT_TRIAL_NUX_STREAM_COACH_MARK = 488;
    DISMISSIBLE_CONTENT_TIERED_TENURE_BADGE_COACHMARK = 491;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_ONBOARDING_ANNOUNCEMENT_MODAL = 492;
    DISMISSIBLE_CONTENT_CONFETTI_POTION_UPSELL = 494;
    DISMISSIBLE_CONTENT_SHARE_ACTIVITY_COACHMARK_V2 = 496;
    DISMISSIBLE_CONTENT_VOICE_FILTER_LOOPBACK_COACHMARK = 497;
    DISMISSIBLE_CONTENT_VOICE_FILTER_LAUNCH_COACHMARK = 498;
    DISMISSIBLE_CONTENT_VOICE_FILTER_IN_CALL_COACHMARK = 499;
    DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE_V2 = 500;
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_NUX = 501;
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_SWITCH_FROM_IP_NUX = 502;
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_NUX = 503;
    DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_SWITCH_FROM_IP_NUX = 504;
    DISMISSIBLE_CONTENT_OVERLAY_OOP_SETTINGS_NUX = 505;
    DISMISSIBLE_CONTENT_Q1_2025_REVERSE_TRIAL = 506;
    DISMISSIBLE_CONTENT_Q1_2025_FOLLOW_UP_REVERSE_TRIAL_OFFER = 507;
    DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_COACHMARK = 508;
    DISMISSIBLE_CONTENT_SWIPE_TO_MEMBER_LIST_COACHMARK = 512;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_ONBOARDING_COACHMARK = 513;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_SHOP_ONBOARDING_COACHMARK = 514;
    DISMISSIBLE_CONTENT_CLICKER_COACHMARK = 515;
    DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_MENU_NEW_BADGE = 516;
    DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_PROFILE_PAGE_NEW_BADGE = 517;
    DISMISSIBLE_CONTENT_PERMADECOS_NITRO_TAB_NEW_BADGE = 518;
    DISMISSIBLE_CONTENT_PERMADECOS_NITRO_HOME_CARD_NEW_BADGE = 520;
    DISMISSIBLE_CONTENT_RING_USER_TO_VC_NEW_BADGE = 522;
    DISMISSIBLE_CONTENT_DESKTOP_REFRESH_ONBOARDING_MODAL = 525;
    DISMISSIBLE_CONTENT_GUILD_POWERUP_NOTIFICATION = 529;
    DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK = 530;
    DISMISSIBLE_CONTENT_GUILD_POWERUP_PERKS_COACHMARK = 531;
    DISMISSIBLE_CONTENT_THIRD_PARTY_OUTBOUND_PROMO_NAGBAR = 532;
    DISMISSIBLE_CONTENT_GUILD_TAG_USER_PROFILE_NEW_BADGE = 534;
    DISMISSIBLE_CONTENT_GUILD_TAG_SERVER_SETTINGS_NEW_BADGE = 535;
    DISMISSIBLE_CONTENT_GUILD_SETTINGS_ROLE_STYLES_NEW_BADGE = 536;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_IGNORE_USER_FEEDBACK = 537;
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_SURVEY_NOTICE = 538;
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_NITRO_TAB_BADGE_V2 = 539;
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FIRST_IMPRESSION_MODAL = 540;
    DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FOLLOW_UP_MODAL = 541;
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_NEW_TAG = 542;
    DISMISSIBLE_CONTENT_NITRO_TENURE_BADGE_LEVEL_UP = 544;
    DISMISSIBLE_CONTENT_ROBLOX_CONNECTION_COACHMARK = 545;
    DISMISSIBLE_CONTENT_VOICE_FILTER_FIRST_USE_COACHMARK = 546;
    DISMISSIBLE_CONTENT_CHANNEL_REORDER_MODAL_DISMISS_SETTING = 547;
    DISMISSIBLE_CONTENT_CUSTOM_THEME_COACHMARK = 548;
    DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_COACHMARK = 549;
    DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_PREMIUM_TAB_BADGE = 550;
    DISMISSIBLE_CONTENT_CLIENT_THEMES_APPEARANCE_SETTINGS_NEW_BADGE = 551;
    DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_NEW_BADGE = 552;
    DISMISSIBLE_CONTENT_MOBILE_BOGO_PROMOTION_ACTION_SHEET = 553;
    DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_GRADIENT = 554;
    DISMISSIBLE_CONTENT_TIERLESS_BOOSTING_SYSTEM_MESSAGE = 555;
    DISMISSIBLE_CONTENT_GOOGLE_PLAY_PRICE_CHANGE_ACTION_SHEET = 556;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_NITRO_TAB_BADGE = 557;
    DISMISSIBLE_CONTENT_ACTIVITIES_VOICE_LAUNCHER_BADGE = 558;
    DISMISSIBLE_CONTENT_BOGO_2025_NITRO_TAB_BADGE = 559;
    DISMISSIBLE_CONTENT_BOGO_2025_ANNOUNCEMENT_MODAL = 560;
    DISMISSIBLE_CONTENT_NITRO_PRIVATE_BROWSING_SURVEY = 563;
    DISMISSIBLE_CONTENT_GUILD_POWERUP_NEW_PERK_AVAILABLE_COACHMARK = 564;
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_EDUCATIONAL_POPOVER = 565;
    DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_CLOSE = 566;
    DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_GET_STARTED = 567;
    DISMISSIBLE_CONTENT_GUILD_PIN_PERMISSION_MIGRATION_NOTIFICATION = 568;
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_NOTIFICATION = 569;
    DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_MODAL = 570;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_REHEAT_COACHMARK = 571;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_COACHMARK = 572;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE = 573;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_OFFER_EXPIRING = 574;
    DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_FILTER_NEW_BADGE = 575;
    DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_SEARCH_RESULTS_HINT = 576;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER = 577;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE_PROFILE_PAGE = 579;
    DISMISSIBLE_CONTENT_CLOUD_PLAY_NEW_BADGE = 580;
    DISMISSIBLE_CONTENT_ACCESSIBILITY_HIGH_CONTRAST_MODE_NEW_BADGE = 583;
    DISMISSIBLE_CONTENT_WIDGETS_RTC_UPSELL_COACHMARK = 584;
    DISMISSIBLE_CONTENT_CLOUD_PLAY_POPOVER = 585;
    DISMISSIBLE_CONTENT_CUSTOM_THEMES_NITRO_HOME_TILE = 586;
    DISMISSIBLE_CONTENT_GUILD_HEADER_BOOST_PROGRESS_BAR_UPSELL = 587;
    DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_NEW_BADGE = 588;
    DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_PROFILE_PAGE_NEW_BADGE = 589;
    DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_COACHMARK = 591;
    DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_BADGE = 592;
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_UPSELL = 593;
    DISMISSIBLE_CONTENT_NITRO_DROP_REWARD = 594;
    DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_BADGE = 595;
    DISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_COACHMARK = 596;
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_REMINDER = 597;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_ANNOUNCEMENT_MODAL = 598;
    DISMISSIBLE_CONTENT_SEPTEMBER_MARKETING_MOMENT_ANNOUNCEMENT_MODAL = 599;
    DISMISSIBLE_CONTENT_DO_NOT_DISTURB_REMINDER_POPOVER = 600;
    DISMISSIBLE_CONTENT_ACCOUNT_LINK_INVITE_FRIENDS = 601;
    DISMISSIBLE_CONTENT_POST_ACCOUNT_CONNECTION_RTC_POPOVER = 602;
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_WEB_BADGE = 603;
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_MOBILE_BADGE = 604;
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TRICK_ICON_WEB_BADGE = 605;
    DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TREAT_ICON_WEB_BADGE = 606;
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_DM_HOME_BANNER = 607;
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_CHAT_BOTTOM_BANNER = 608;
    DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_APP_START_BOTTOM_SHEET = 609;
    DISMISSIBLE_CONTENT_ACCOUNT_LINK_PROMPT = 610;
    DISMISSIBLE_CONTENT_WISHLIST_NUX_TOOLTIP_AND_MODAL = 611;
    DISMISSIBLE_CONTENT_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_NEW_BADGE = 613;
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_PORTKEY_TOS = 614;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_NEW_BADGE = 615;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_LINKED = 616;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_UNLINKED = 617;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_CONNECT = 618;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_ADD_WIDGET = 619;
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_BADGE = 620;
    DISMISSIBLE_CONTENT_WISHLIST_SHOP_BUTTON_POPOVER = 621;
    DISMISSIBLE_CONTENT_HANG_STATUS_POPOVER_NUX = 622;
    DISMISSIBLE_CONTENT_REPORT_TO_MOD_EXIT_SURVEY_NOTICE = 623;
    DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PASSKEY_BACKUP = 624;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NITRO_HOME_TILE = 625;
    DISMISSIBLE_CONTENT_CROSS_DM_SEARCH_SETTING_EDUCATION_POPOVER = 627;
    DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_COUNTDOWN = 630;
    DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_HALLOWEEN_2025 = 631;
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_ONBOARDING = 632;
    DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_ANNOUNCEMENT_UPSELL = 633;
    DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_OFFER_REMINDER = 634;
    DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_PILL = 635;
    DISMISSIBLE_CONTENT_GAME_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_UPSELL = 636;
    DISMISSIBLE_CONTENT_RECURRING_3P_PROMOTION_POPOVER = 637;
    DISMISSIBLE_CONTENT_PREMIUM_TAB_MARKETING_MOMENT_OFFER_BADGE = 638;
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_COACHMARK = 639;
    DISMISSIBLE_CONTENT_GAME_SHOP_NEW_BADGE = 640;
    DISMISSIBLE_CONTENT_GAME_SHOP_RTC_POPOVER = 641;
    DISMISSIBLE_CONTENT_GUILD_JOINT_PERMISSION_MIGRATION_NOTIFICATION = 642;
    DISMISSIBLE_CONTENT_GAME_SHOP_ANNOUNCEMENT_MODAL = 643;
    DISMISSIBLE_CONTENT_CHECKPOINT_2025_BOTTOM_SHEET = 644;
    DISMISSIBLE_CONTENT_GAME_SHOP_WISHLIST_POPOVER = 645;
    DISMISSIBLE_CONTENT_DISCOUNT_OFFER_ACTION_SHEET = 646;
    DISMISSIBLE_CONTENT_MOBILE_PREMIUM_TRIAL_OFFER_ACTION_SHEET = 647;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_ANNOUNCEMENT_MODAL = 648;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_NEW_BADGE = 649;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_WIDE_BANNER = 650;
    DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_BETA_COACHMARK = 651;
    DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_PROFILE_TOOLTIP = 653;
    DISMISSIBLE_CONTENT_CHECKPOINT_2025_DESKTOP_UPSELL = 654;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_SUGGESTED_WIDGET = 655;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_LINKED = 656;
    DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_UNLINKED = 657;
    DISMISSIBLE_CONTENT_INSTALLED_GAME_COMMUNITY_UPSELL = 658;
    DISMISSIBLE_CONTENT_GAME_SHOP_RTC_GIFTING_NEW_BADGE = 659;
    DISMISSIBLE_CONTENT_GAME_INVITE_ACCOUNT_LINK_UPSELL = 660;
    DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_NEW_BADGE_V2 = 661;
    DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK_V2 = 662;
    DISMISSIBLE_CONTENT_GUILD_TAG_UPDATED_COACHMARK = 663;
    DISMISSIBLE_CONTENT_ORB_RENTAL_NEW_BADGE = 664;
    DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_WINTER_2025 = 665;
    DISMISSIBLE_CONTENT_WISHLIST_USER_PROFILE_ACCOUNT_POPOUT_UPSELL = 666;
    DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_2026_SETTINGS_BADGE = 667;
    DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER = 668;
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_UPSELL_POPOVER = 669;
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_DROP_POPOVER = 670;
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_PERK_AVAILABLE_COACHMARK = 672;
    DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_INTRO_POPOVER = 673;
    DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_ADMIN_COACHMARK = 674;
    DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_MEMBER_COACHMARK = 675;
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_TAKEOVER_BADGE = 676;
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_XBOX_ANNOUNCEMENT = 677;
    DISMISSIBLE_CONTENT_BOOST_TO_UNLOCK_COACHMARK = 678;
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_PRODUCT_CARD_COACHMARK = 679;
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_ACTION_SHEET = 680;
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_YOU_SCREEN_COACHMARK = 681;
    DISMISSIBLE_CONTENT_GAME_CLAIM_COACHMARK = 682;
    DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_MARVEL_RIVALS_ORBS_REWARD = 683;
    DISMISSIBLE_CONTENT_EXPIRING_POWERUP_COACHMARK = 684;
    DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL = 685;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER_V2 = 686;
    DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_HERO_BADGE = 687;
    DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_COACHMARK = 688;
    DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_NEW_BADGE = 689;
    DISMISSIBLE_CONTENT_JOIN_GAME_COMMUNITY_RTC_CTA = 690;
    DISMISSIBLE_CONTENT_NAGBAR_QUEST_APP_UPSELL = 691;
    DISMISSIBLE_CONTENT_GAME_SHOP_ORBS_REWARD_BANNER = 692;
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARDS_ANNOUNCEMENT = 693;
    DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_INTRO = 694;
    DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_MENU_ITEM = 695;
    DISMISSIBLE_CONTENT_GIFT_INTENT_MESSAGE = 696;
    DISMISSIBLE_CONTENT_MOBILE_REFERRAL_PROGRAM_BOTTOM_SHEET_ENTRYPOINT = 697;
    DISMISSIBLE_CONTENT_GAME_ACCOUNT_LINK_RECURRING_UPSELL = 698;
    DISMISSIBLE_CONTENT_WISHLIST_MOBILE_VIEWER_COACHMARK = 699;
    DISMISSIBLE_CONTENT_EMPTY_GAME_SERVER_TAB = 700;
    DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_VIDEO_CARD = 701;
    DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARD_WISHLIST_UPSELL = 702;
    DISMISSIBLE_CONTENT_USER_PROFILE_WISHLIST_RECOMMENDATIONS = 703;
    DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_BATCH_RELEASE_V2_COACHMARK = 704;
    DISMISSIBLE_CONTENT_QUEST_ACTIVITY_HEADER_INTRO = 705;
    DISMISSIBLE_CONTENT_GAME_SERVER_GAME_DETECTION_UPSELL_NEW_BADGE = 706;
    DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_ENTRYPOINT_NITRO_TAB_BADGE = 707;
    DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_EXPANDED_UPSELL = 708;
    DISMISSIBLE_CONTENT_FAVORITES_GUILD_NEW_BADGE = 709;
    DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL_OVERSEER = 710;
    DISMISSIBLE_CONTENT_MOBILE_MULTI_GUILD_CREATE_UPSELL_ANIMATION = 711;
    DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_REMINDER_UPSELL = 712;
    DISMISSIBLE_CONTENT_GAME_SERVER_PRICING_CHANGE_COACHMARK = 713;
    DISMISSIBLE_CONTENT_PREMIUM_WISHLIST_COACHMARK = 714;
    DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER_UPSELL_V2 = 715;
    DISMISSIBLE_CONTENT_L_3PP_NON_NITRO_POPOVER = 716;
    DISMISSIBLE_CONTENT_L_3PP_NITRO_TOOLTIP = 717;
  }

  message MobileBottomSheet {
    string asset_url = 1;
    string header = 2;
    string body = 3;
    string help_article_id = 4;
    optional CTAButton button = 5;
    DismissibleContent dismissible_content = 6;
  }

  message Gradient {
    repeated string colors = 1 [packed = false];
    float angle = 2;
  }

  message GiftIcon {
    string box_animation_url = 1;
    string trinket_animation_url = 2;
    string trinket_glow_animation_url = 3;
    optional Gradient gradient = 4;
  }

  message ThemeAwareAsset {
    string light_url = 1;
    string dark_url = 2;
    string light_static_url = 3;
    string dark_static_url = 4;
  }

  message GiftIconCoachmark {
    string header = 1;
    string body = 2;
    string asset_url = 3;
    optional ThemeAwareAsset asset = 4;
  }

  message GiftPlanSelectionCardBanner {
    string header = 1;
    string desktop_body = 2;
    string mobile_body = 3;
    optional ThemeAwareAsset avatar_asset = 4;
    string banner_asset_url = 5;
    string background_asset_url = 6;
    string card_asset_url = 7;
    optional Gradient gradient = 8;
    optional ThemeAwareAsset banner_asset = 9;
    optional ThemeAwareAsset background_asset = 10;
    optional ThemeAwareAsset card_asset = 11;
    optional ThemeAwareAsset mobile_banner_asset = 12;
  }

  message GiftCustomizationBanner {
    string asset_url = 1;
    string desktop_body = 2;
    string mobile_body = 3;
    optional Gradient gradient = 4;
    string background_asset_url = 5;
    optional ThemeAwareAsset asset = 6;
    optional ThemeAwareAsset background_asset = 7;
    optional ThemeAwareAsset mobile_background_asset = 8;
  }

  message BillingSettingsNitroGiftBanner {
    string asset_url = 1;
    string header = 2;
    string body = 3;
    string background_asset_url = 4;
    optional Gradient gradient = 5;
    string text_color = 6;
    string additional_terms = 7;
    optional ThemeAwareAsset asset = 8;
    optional ThemeAwareAsset background_asset = 9;
  }

  message GiftReminderNagbar {
    string body = 1;
  }

  message GiftReminderCoachmark {
    string header = 1;
    string body = 2;
    string asset_url = 3;
    optional ThemeAwareAsset asset = 4;
  }

  message PremiumTabTooltip {
    string header = 1;
    string body = 2;
    optional ThemeAwareAsset asset = 3;
  }

  string content_identifier = 3;
  oneof properties {
    string placeholder = 1;
    AnnouncementModalVariant1Properties announcement_modal_variant_1 = 2;
    PremiumTab premium_tab = 4;
    MarketingPageBanner marketing_page_banner = 5;
    PaymentModalBanner payment_modal_banner = 6;
    MobileBottomSheet mobile_bottom_sheet = 7;
    GiftIcon gift_icon = 8;
    GiftIconCoachmark gift_icon_coachmark = 9;
    GiftPlanSelectionCardBanner gift_plan_selection_card_banner = 10;
    GiftCustomizationBanner gift_customization_banner = 11;
    BillingSettingsNitroGiftBanner billing_settings_nitro_gift_banner = 12;
    GiftReminderNagbar gift_reminder_nagbar = 13;
    GiftReminderCoachmark gift_reminder_coachmark = 14;
    PremiumTabTooltip premium_tab_tooltip = 15;
  }

}
